package config

import (
	"flag"

	"git.paulbsd.com/paulbsd/qrz/utils"
	"gopkg.in/ini.v1"
	"xorm.io/xorm"
)

// GetConfig fetch configuration
func (config *Config) GetConfig() error {
	var configfile string
	var nofeed bool
	var debug bool
	var port int

	flag.Usage = utils.Usage

	flag.StringVar(&configfile, "configfile", "qrz.ini", "config file to use with qrz section")
	flag.IntVar(&port, "port", 8080, "web port to use")
	flag.BoolVar(&nofeed, "nofeed", false, "no feed database table with entries at first launch")
	flag.BoolVar(&debug, "debug", false, "if debug logging must be enabled")
	flag.Parse()

	cfg, err := ini.Load(configfile)
	if err != nil {
		return err
	}

	qrzsection := cfg.Section("qrz")

	config.Port = port
	config.NoFeed = nofeed
	config.Debug = debug
	config.DbHostname = qrzsection.Key("db_hostname").MustString("localhost")
	config.DbName = qrzsection.Key("db_name").MustString("database")
	config.DbUsername = qrzsection.Key("db_username").MustString("username")
	config.DbPassword = qrzsection.Key("db_password").MustString("password")
	config.Cron = qrzsection.Key("cron").MustString("@every 1h")

	config.URLBase = `http://groupe-frs.hamstation.eu/index_qrz_liste_%s.php`

	config.QrzGroups = []string{
		"01",
		"03",
		"09",
		"103",
		"104",
		"107",
		"119",
		"13",
		"14",
		"146",
		"147",
		"15",
		"156",
		"16",
		"161",
		"163",
		"18",
		"188",
		"2",
		"214",
		"233",
		"25",
		"26",
		"29",
		"30",
		"31",
		"32",
		"34",
		"43",
		"44",
		"49",
		"54",
		"64",
		"66",
		"76",
		"79",
		"84",
		"97",
		"98"}

	return nil
}

// Config is the global config of qrz
type Config struct {
	Db         *xorm.Engine
	DbHostname string
	DbName     string
	DbUsername string
	DbPassword string
	URLBase    string
	QrzGroups  []string
	Cron       string
	Port       int
	NoFeed     bool
	Debug      bool
	Version    string
}
